ASS_FEATURE_INCOMPATIBLE_EXTENSIONS constant

int const ASS_FEATURE_INCOMPATIBLE_EXTENSIONS

Enable libass extensions that would display ASS subtitles incorrectly. These may be useful for applications, which use libass as renderer for subtitles converted from another format, or which use libass for other purposes that do not involve actual ASS subtitles authored for distribution.

Implementation

static const int ASS_FEATURE_INCOMPATIBLE_EXTENSIONS = 0;